import * as hmUI from "@zos/ui";
import { log as Logger } from "@zos/utils";
import {
  FETCH_BUTTON,
  FETCH_RESULT_TEXT,
} from "zosLoader:./index.[pf].layout.js";

import HeartRateSensor from "./sensors/heartRate";
import StressSensor from "./sensors/stress";
import AccelerometerSensor from "./sensors/accelerometer"; 

const logger = Logger.getLogger("fetch_api");

Page({
  data: {
    heartRate: 0,
    stress: 0,
    accelerometer: { x: 0, y: 0, z: 0 },
    isUpdating: false,
  },

  build() {
    console.log("Building UI");

    hmUI.createWidget(hmUI.widget.BUTTON, {
      ...FETCH_BUTTON,
      click_func: () => {
        logger.log("Fetch button clicked");
        this.startPeriodicUpdates();
      },
    });

    this.sensorDataTextWidget = hmUI.createWidget(hmUI.widget.TEXT, {
      ...FETCH_RESULT_TEXT,
      text: "",
    });

    this.initializeSensors();
  },

  initializeSensors() {
    console.log("Initializing sensors");

    this.heartRateSensor = new HeartRateSensor();
    this.heartRateSensor.init();

    this.stressSensor = new StressSensor();
    this.stressSensor.init();

    this.accelerometerSensor = new AccelerometerSensor();
    this.accelerometerSensor.init();

    console.log("Sensors initialized");
  },

  startPeriodicUpdates() {
    if (this.data.isUpdating) {
      logger.log("Periodic updates already running.");
      return;
    }

    console.log("Starting periodic updates.");
    this.data.isUpdating = true;

    this.updateUI();

    this.uiUpdateInterval = setInterval(() => {
      this.updateUI();
    }, 1000);
  },

  updateUI() {
    console.log("Fetching sensor data for UI update");

    const currentHeartRate = this.heartRateSensor.getCurrentValue();
    const currentStress = this.stressSensor.getCurrentValue();
    const currentAccelerometer = this.accelerometerSensor.getCurrentValue();

    const sensorDataText = `
      Heart Rate: ${currentHeartRate || "--"} bpm
      Stress Level: ${currentStress.value || 0}
        Accelerometer: x=${currentAccelerometer.x.toFixed(1)||0.}, y=${currentAccelerometer.y.toFixed(1) || 0}, z=${currentAccelerometer.z.toFixed(1) || 0}
    `;

    this.sensorDataTextWidget.setProperty(hmUI.prop.TEXT, sensorDataText.trim());
    logger.log("UI updated with current sensor data.");
  },

  onDestroy() {
    if (this.uiUpdateInterval) clearInterval(this.uiUpdateInterval);
    if (this.stressSensor) this.stressSensor.stop();
    if (this.accelerometerSensor) this.accelerometerSensor.stop();
  },
});
