import { Accelerometer, FREQ_MODE_LOW } from "@zos/sensor";

export default class AccelerometerSensor {
  constructor() {
    this.accelerometer = new Accelerometer();
    this.currentData = { x: 0, y: 0, z: 0 }; 
  }

  init(callback) {
    console.log("Initializing Accelerometer Sensor");

    try {
      this.accelerometer.setFreqMode(FREQ_MODE_LOW);

      this.accelerometer.onChange(() => {
        const data = this.accelerometer.getCurrent();
        console.log("Current Accelerometer Data:", data);

        if (data) {
          this.currentData = data;

          if (callback) callback(data);
        } else {
          console.warn("Accelerometer value is undefined or null");
        }
      });

      this.accelerometer.start();
      console.log("Accelerometer started successfully.");
    } catch (error) {
      console.error("Error initializing Accelerometer Sensor:", error);
    }
  }

  getCurrentValue() {
    return this.currentData;
  }

  stop() {
    try {
      this.accelerometer.stop();
      console.log("Accelerometer stopped successfully.");
    } catch (error) {
      console.error("Error stopping Accelerometer Sensor:", error);
    }
  }
}
