import { BloodOxygen } from "@zos/sensor";
import { LocalStorage } from "@zos/storage";

export default class BloodOxygenSensor {
  constructor() {
    this.bloodOxygen = new BloodOxygen();
    this.localStorage = new LocalStorage();
  }

  init(callback) {
    console.log("Initializing Blood Oxygen Sensor");

    try {
      this.bloodOxygen.onChange(() => {
        const data = this.bloodOxygen.getCurrent();
        console.log("Blood Oxygen data:", data);

        if (data && data.value !== undefined) {
          console.log("Valid Blood Oxygen Data:", { value: data.value });
          this.saveDataToStorage("bloodOxygen", { value: data.value });

          if (callback) callback(data);
        } else {
          console.warn("Blood Oxygen value is undefined or null.");
        }
      });

      this.bloodOxygen.start();
      console.log("Blood Oxygen sensor started successfully.");
    } catch (error) {
      console.error("Error initializing Blood Oxygen Sensor:", error);
    }
  }

  saveDataToStorage(sensorType, data) {
    const timestamp = new Date().toISOString();
    const sensorData = { ...data, timestamp };

    try {
      this.localStorage.setItem(sensorType, JSON.stringify(sensorData));
      console.log(`Saved ${sensorType} data:`, sensorData);
    } catch (error) {
      console.error(`Failed to save ${sensorType} data:`, error);
    }
  }

  getDataFromStorage() {
    try {
      const bloodOxygenData = JSON.parse(this.localStorage.getItem("bloodOxygen"));
      console.log("Fetched Blood Oxygen Data from storage:", bloodOxygenData);
      return bloodOxygenData || { value: null };
    } catch (error) {
      console.error("Error fetching Blood Oxygen data from storage:", error);
      return { value: null };
    }
  }

  stop() {
    try {
      this.bloodOxygen.stop();
      console.log("Blood Oxygen sensor stopped successfully.");
    } catch (error) {
      console.error("Error stopping Blood Oxygen Sensor:", error);
    }
  }
}
