import { Geolocation } from "@zos/sensor";
import { LocalStorage } from "@zos/storage";

export default class GeolocationSensor {
  constructor() {
    this.geolocation = new Geolocation();
    this.localStorage = new LocalStorage();
  }

  init(callback) {
    console.log("Initializing Geolocation Sensor");

    try {
      this.geolocation.onChange((data) => {
        console.log("Geolocation onChange triggered. Raw Data:", data);

        if (data && data.latitude && data.longitude) {
          const formattedLatitude = this.formatGeolocation(data.latitude);
          const formattedLongitude = this.formatGeolocation(data.longitude);

          console.log("Formatted Geolocation Data received:", {
            latitude: formattedLatitude,
            longitude: formattedLongitude,
          });

          this.saveDataToStorage("geolocation", {
            latitude: formattedLatitude,
            longitude: formattedLongitude,
          });

          if (callback) {
            callback({
              latitude: formattedLatitude,
              longitude: formattedLongitude,
            });
          }
        } else {
          console.warn("Invalid Geolocation Data:", data);
        }
      });

      this.geolocation.start();
      console.log("Geolocation sensor started successfully.");
    } catch (error) {
      console.error("Error initializing Geolocation Sensor:", error);
    }
  }

  formatGeolocation(geoObject) {
    return `${geoObject.direction} ${geoObject.degrees}°${geoObject.minutes}'${geoObject.seconds}"`;
  }

  saveDataToStorage(sensorType, data) {
    const timestamp = new Date().toISOString();
    const sensorData = { ...data, timestamp };

    try {
      this.localStorage.setItem(sensorType, JSON.stringify(sensorData));
      console.log(`Saved ${sensorType} data:`, sensorData);
    } catch (error) {
      console.error(`Failed to save ${sensorType} data:`, error);
    }
  }

  getDataFromStorage() {
    try {
      const geolocationData = JSON.parse(this.localStorage.getItem("geolocation"));
      console.log("Fetched Geolocation Data from storage:", geolocationData);
      return geolocationData || {
        latitude: "N/A",
        longitude: "N/A",
      };
    } catch (error) {
      console.error("Error fetching Geolocation data from storage:", error);
      return { latitude: "N/A", longitude: "N/A"};
    }
  }
}
