import { Gyroscope, FREQ_MODE_LOW } from "@zos/sensor";
import { LocalStorage } from "@zos/storage";

export default class GyroscopeSensor {
  constructor() {
    this.gyroscope = new Gyroscope();
    this.localStorage = new LocalStorage();
  }

  init(callback) {
    console.log("Initializing Gyroscope Sensor");

    try {
        this.gyroscope.setFreqMode(FREQ_MODE_LOW);
      
        this.gyroscope.onChange(() => {
          const data = this.gyroscope.getCurrent(); 
          console.log("Current Gyroscope Data:", data);
      
          if (data) {
            this.saveDataToStorage("gyroscope", data);
      
            if (callback) callback(data);
          } else {
            console.warn("Gyroscope value is undefined or null");
          }
        });
      
        // Start the gyroscope sensor
        this.gyroscope.start();
        console.log("Gyroscope started successfully.");
      } catch (error) {
        console.error("Error initializing Gyroscope Sensor:", error);
      }
      
  }

  saveDataToStorage(sensorType, data) {
    const timestamp = new Date().toISOString();
    const sensorData = { ...data, timestamp };

    try {
      this.localStorage.setItem(sensorType, JSON.stringify(sensorData));
      console.log(`Saved ${sensorType} data:`, sensorData);
    } catch (error) {
      console.error(`Failed to save ${sensorType} data:`, error);
    }
  }

  getDataFromStorage() {
    try {
      const gyroscopeData = JSON.parse(this.localStorage.getItem("gyroscope"));
      return gyroscopeData || { x: 0, y: 0, z: 0 };
    } catch (error) {
      console.error("Error fetching Gyroscope data from storage:", error);
      return { x: 0, y: 0, z: 0 };
    }
  }

  stop() {
    try {
      this.gyroscope.stop();
      console.log("Gyroscope stopped successfully.");
    } catch (error) {
      console.error("Error stopping Gyroscope Sensor:", error);
    }
  }
}
