import { Step } from "@zos/sensor";
import { LocalStorage } from "@zos/storage";

export default class StepSensor {
  constructor() {
    this.step = new Step();
    this.localStorage = new LocalStorage();
  }

  init(callback) {
    console.log("Initializing Step Sensor");

    try {
      this.step.onChange(() => {
        const current = this.step.getCurrent();
        console.log("Current Step Data received:", current);

        if (current !== undefined) {
          this.saveDataToStorage("step", { step: current });

          if (callback) {
            callback({ step: current });
          }
        } else {
          console.warn("Invalid Step Data received from getCurrent");
        }
      });

      console.log("Step sensor started successfully.");
    } catch (error) {
      console.error("Error initializing Step Sensor:", error);
    }
  }

  saveDataToStorage(sensorType, data) {
    const timestamp = new Date().toISOString();
    const sensorData = { ...data, timestamp };

    try {
      this.localStorage.setItem(sensorType, JSON.stringify(sensorData));
      console.log(`Saved ${sensorType} data:`, sensorData);
    } catch (error) {
      console.error(`Failed to save ${sensorType} data:`, error);
    }
  }

  getDataFromStorage() {
    try {
      const stepData = JSON.parse(this.localStorage.getItem("step"));
      console.log("Fetched Step Data from storage:", stepData);
      return stepData || { step: 0 };
    } catch (error) {
      console.error("Error fetching Step data from storage:", error);
      return { step: 0 };
    }
  }

  stop() {
    try {
      this.step.stop();
      console.log("Step sensor stopped successfully.");
    } catch (error) {
      console.error("Error stopping Step Sensor:", error);
    }
  }
}
